@@ -157,7 +157,7 @@ nouveau_exa_destroy_pixmap(ScreenPtr pScreen, void *priv)
 
 #ifdef NOUVEAU_PIXMAP_SHARING
 static Bool
-nouveau_exa_share_pixmap_backing(PixmapPtr ppix, ScreenPtr slave, void **handle_p)
+nouveau_exa_share_pixmap_backing(PixmapPtr ppix, ScreenPtr secondary, void **handle_p)
 {
 	struct nouveau_bo *bo = nouveau_pixmap_bo(ppix);
 	struct nouveau_pixmap *nvpix = nouveau_pixmap(ppix);
@@ -514,12 +514,13 @@ nouveau_exa_init(ScreenPtr pScreen)
 		break;
 	case NV_FERMI:
 	case NV_KEPLER:
+	case NV_MAXWELL:
+	case NV_PASCAL:
 		exa->CheckComposite   = NVC0EXACheckComposite;
 		exa->PrepareComposite = NVC0EXAPrepareComposite;
 		exa->Composite        = NVC0EXAComposite;
 		exa->DoneComposite    = NVC0EXADoneComposite;
 		break;
-	case NV_MAXWELL:
 	default:
 		break;
 	}
