@@ -17,6 +17,8 @@ typedef enum {
     OPTION_PAGE_FLIP,
     OPTION_SWAP_LIMIT,
     OPTION_ASYNC_COPY,
+    OPTION_ACCELMETHOD,
+    OPTION_DRI,
 } NVOpts;
 
 
@@ -32,6 +34,8 @@ static const OptionInfoRec NVOptions[] = {
     { OPTION_PAGE_FLIP,		"PageFlip",	OPTV_BOOLEAN,	{0}, FALSE },
     { OPTION_SWAP_LIMIT,	"SwapLimit",	OPTV_INTEGER,	{0}, FALSE },
     { OPTION_ASYNC_COPY,	"AsyncUTSDFS",	OPTV_BOOLEAN,	{0}, FALSE },
+    { OPTION_ACCELMETHOD,	"AccelMethod",	OPTV_STRING,	{0}, FALSE },
+    { OPTION_DRI,		"DRI",		OPTV_INTEGER,	{0}, FALSE },
     { -1,                       NULL,           OPTV_NONE,      {0}, FALSE }
 };
 
